@@ -1,8 +1,11 @@
+from __future__ import absolute_import
+
+from functools import wraps
 import os
 import time
 import configparser
 from munch import Munch
-from .exceptions import CoprNoConfigException, CoprConfigException, CoprException
+from .exceptions import CoprConfigException, CoprException
 
 
 class List(list):
@@ -24,12 +27,14 @@ def config_from_file(path=None):
         raise CoprConfigException(str(ex))
 
     if not exists:
-        raise CoprNoConfigException("There is no config file: {}".format(path))
+        raw_config["copr-cli"] = {"copr_url": "https://copr.fedorainfracloud.org"}
 
     try:
-        for field in ["username", "login", "token", "copr_url"]:
+        for field in ["username", "login", "token", "copr_url", "gssapi"]:
             config[field] = raw_config["copr-cli"].get(field, None)
         config["encrypted"] = raw_config["copr-cli"].getboolean("encrypted", True)
+        config["gssapi"] = raw_config["copr-cli"].getboolean("gssapi")
+
 
     except configparser.Error as err:
         raise CoprConfigException("Bad configuration file: {0}".format(err))
@@ -58,6 +63,7 @@ def bind_proxy(func):
     Modify a result munch and set the __proxy__ parameter
     to the actual proxy instance.
     """
+    @wraps(func)
     def wrapper(*args, **kwargs):
         result = func(*args, **kwargs)
         if type(result) not in [List, Munch]:
