@@ -1,7 +1,8 @@
 import os
-from ..helpers import config_from_file
-from ..requests import Request, munchify
-from ..helpers import for_all_methods, bind_proxy
+
+from copr.v3.auth import auth_from_config
+from copr.v3.requests import munchify, Request
+from ..helpers import for_all_methods, bind_proxy, config_from_file
 
 
 @for_all_methods(bind_proxy)
@@ -12,6 +13,11 @@ class BaseProxy(object):
 
     def __init__(self, config):
         self.config = config
+        self.request = Request(
+            api_base_url=self.api_base_url,
+            connection_attempts=config.get("connection_attempts", 1)
+        )
+        self._auth = None
 
     @classmethod
     def create_from_config_file(cls, path=None):
@@ -24,7 +30,9 @@ class BaseProxy(object):
 
     @property
     def auth(self):
-        return self.config["login"], self.config["token"]
+        if not self._auth:
+            self._auth = auth_from_config(self.config)
+        return self._auth
 
     def home(self):
         """
@@ -33,8 +41,7 @@ class BaseProxy(object):
         :return: Munch
         """
         endpoint = ""
-        request = Request(endpoint, api_base_url=self.api_base_url)
-        response = request.send()
+        response = self.request.send(endpoint=endpoint)
         return munchify(response)
 
     def auth_check(self):
@@ -44,6 +51,12 @@ class BaseProxy(object):
         :return: Munch
         """
         endpoint = "/auth-check"
-        request = Request(endpoint, api_base_url=self.api_base_url, auth=self.auth)
-        response = request.send()
+        response = self.request.send(endpoint=endpoint, auth=self.auth)
         return munchify(response)
+
+    def auth_username(self):
+        """
+        Return the username (string) assigned to this configuration.  May
+        contact the server and authenticate if needed.
+        """
+        return self.auth.username
